| linf.csts | R Documentation |
Forms provisional depth-1 dominance sample sets from the dominant feature
of each sample and then applies the minimum support threshold n0.
Sets with fewer than n0 samples are handled according to
low.freq.policy:
"pure": retain only sets with support >= n0 as named
dCSTs and collapse all low-support sets into rare.label.
"absorb": reassign each low-support sample to the retained
state with the largest value among the retained features (ties handled
by tie.method).
linf.csts(
S,
feature.ids = NULL,
feature.labels = NULL,
n0 = 50,
low.freq.policy = c("pure", "absorb"),
rare.label = "RARE_DOMINANT",
tie.method = c("first", "random", "error"),
return.diagnostics = FALSE,
return.landmarks = FALSE,
landmark.types = c("endpoint.max", "endpoint.min"),
landmark.view = c("active", "rare", "absorb"),
backend = c("auto", "dense", "sparse")
)
S |
Numeric matrix (samples x features), typically L-infinity relatives. |
feature.ids |
Optional character vector of stable feature identifiers,
length |
feature.labels |
Optional character vector of display labels, length
|
n0 |
Integer >= 1. Minimum support required to retain a dominance sample set. |
low.freq.policy |
Character. One of |
rare.label |
Character scalar used when |
tie.method |
Character. Tie handling passed to |
return.diagnostics |
Logical. If TRUE, return reassignment diagnostics. |
return.landmarks |
Logical. If TRUE, attach a depth-1 landmark summary
computed by |
landmark.types |
Character vector of landmark types passed to
|
landmark.view |
Character. Landmark view passed to
|
backend |
Character. Matrix backend to use: |
List with:
cell.index, cell.id, cell.label: active labeling per low.freq.policy
cell.index.rare, cell.id.rare, cell.label.rare
cell.index.absorb, cell.id.absorb, cell.label.absorb
kept.cells.idx, kept.cells.id, kept.cells.lbl
raw.index, raw.id, raw.label
feature.ids, feature.labels
size.table, size.table.id
n0, low.freq.policy, rare.label
diagnostics (if return.diagnostics = TRUE)
landmarks (if return.landmarks = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.